@@ -930,7 +930,7 @@ bool SqueezsterCore::playerListsEqual(QVariantList list1, QVariantList list2)
 //----------------------------------------------
 void SqueezsterCore::updateUI() // const QVariantMap &statusMap)
 {
-    _DEBUG_ << "updateUI() Player" << playerStatus()[P_NAME].toString();
+    _DEBUG_ << "updateUI() Player" << playerStatus()[P_NAME].toString() << playerStatus()[P_LOOP].toList();
     if(!playerStatus()[P_LOOP].toList().isEmpty())
         setCurrentSong(playerStatus()[P_LOOP].toList().first().toMap());
 
