@@ -1094,8 +1094,9 @@ void squeezster::listContextMenuHandler(QPoint point) {
             sendRequest("playlistcontrol cmd:play "+QUrl::toPercentEncoding(idStr));
         else if(selectedAction->text().toLower()==QString("add to playlist"))  // albums
             sendRequest("playlistcontrol cmd:add "+QUrl::toPercentEncoding(idStr));
-        else if(selectedAction->text().toLower()==QString("delete from playlist"))
-            sendRequest("playlist delete "+listWidget->row(item));
+        else if(selectedAction->text().toLower()==QString("delete from playlist")) {
+            _DEBUG_ << "playlist delete " << listWidget->row(item);
+            sendRequest("playlist delete "+QString::number(listWidget->row(item)));  }
         else if(selectedAction->text().toLower()==QString("delete playlist")) {
             sendRequest("playlists delete "+QUrl::toPercentEncoding(idStr));
             sendCometRequest("playlists"); }
